.. include:: ./links.inc

git-annex utilities
===================

``datalad-osf`` comes with a git-annex special remote implementation for the OSF.
Find out more by clicking on the module name below.

.. currentmodule:: datalad_osf
.. autosummary::
   :toctree: generated

   annex_remote.OSFSpecialRemote
